ams.opt.expression.Expression
=============================

.. currentmodule:: ams.opt.expression

.. autoclass:: Expression

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Expression.evaluate
       
       
          ~Expression.get_idx
       
       
          ~Expression.parse
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Expression.class_name
      ~Expression.e
      ~Expression.n
      ~Expression.shape
      ~Expression.size
      ~Expression.v
   
   